@@ -6,6 +6,4 @@ from menu import Menu, MenuItem
 
 from core_curate_app.settings import CURATE_MENU_NAME
 
-Menu.add_item(
-    "main", MenuItem(CURATE_MENU_NAME, reverse("core_curate_index"))
-)
+Menu.add_item("main", MenuItem(CURATE_MENU_NAME, reverse("core_curate_index")))
