@@ -12,13 +12,15 @@ from core_curate_app.settings import (
 from core_parser_app.tools.parser.parser import XSDParser
 
 
-def get_parser():
+def get_parser(request=None):
     """Load configuration for the parser.
 
+    Args:
+        request:
+
     Returns:
 
     """
-
     return XSDParser(
         min_tree=PARSER_MIN_TREE,
         ignore_modules=PARSER_IGNORE_MODULES,
@@ -26,4 +28,5 @@ def get_parser():
         auto_key_keyref=PARSER_AUTO_KEY_KEYREF,
         implicit_extension_base=PARSER_IMPLICIT_EXTENSION_BASE,
         download_dependencies=PARSER_DOWNLOAD_DEPENDENCIES,
+        request=request,
     )
